==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/es_AR.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documentos",
"You don't have permission to rename this document" => "No tienes permisos para cambiar de nombre a este documento.",
"Saved" => "Guardado",
"Saving..." => "Guardando...",
"Failed to load documents." => "La carga de documentos ha fallado.",
"No connection to server. Trying to reconnect." => "No hay conexión al servidor. Intentado reconectar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Salir de esta página en modo Editor puede causar pérdida de datos. Es recomendable usar el botón 'Cerrar'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Fallo al cargar este documento. Por favor, chequée si puede ser abierto con un editor odt externo. Esto también puede suceder si ha dejado de compartirse o ha sido borrado recietemente.",
"Save" => "Guardar",
"Loading documents..." => "Cargando documentos...",
"'.' is an invalid file name." => "'.' es un nombre de archivo inválido.",
"File name cannot be empty." => "El nombre del archivo no puede quedar vacío.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nombre invalido, '\\', '/', '<', '>', ':', '\"', '|', '?' y '*' no están permitidos.",
"Align Left" => "Alinear a la izquierda",
"Alignment" => "Alineación",
"Align Right" => "Alinear a la derecha",
"Annotate" => "Anotar",
"Background" => "Fondo",
"Bold" => "Negrita",
"Bottom" => "Abajo",
"Cancel" => "Cancelar",
"Center" => "Centro",
"Clone" => "Clonar",
"Clone this Style" => "Clonar este Estilo",
"Close" => "Cerrar",
"Color" => "Color",
"Create" => "Crear",
"Decrease Indent" => "Disminuir indentación",
"Default Style" => "Estilo Predefinido",
"Delete" => "Borrar",
"Family" => "Familia",
"Font" => "Fuente",
"Font Effects" => "Efectos de Fuente",
"Format" => "Formato",
"Increase Indent" => "Incrementar Indentación",
"Insert Image" => "Insertar Imágen",
"Invite Members" => "Invitar Miembros",
"Italic" => "Itálica",
"Justified" => "Justificado",
"Justify" => "Justificar",
"Left" => "Izquierda",
"Loading" => "Cargando",
"Members" => "Miembros",
"New Name:" => "Nuevo Nombre:",
"OK" => "Aceptar",
"Open" => "Abrir",
"Options" => "Opciones",
"Paragraph..." => "Párrafo...",
"Paragraph Styles" => "Estilos de Párrafo",
"Redo" => "Rehacer",
"Right" => "Derecha",
"Size" => "Tamaño",
"Spacing" => "Espaciado",
"Strikethrough" => "Tachado",
"Style" => "Estilo",
"Text" => "Texto",
"Top" => "Arriba",
"Underline" => "Subrayado",
"Undo" => "Deshacer",
"Unknown Author" => "Autor Desconocido",
"Edit" => "Editar",
"Share" => "Compartir",
"Disabled" => "Deshabilitado",
"New document" => "Nuevo documento",
"Upload" => "Subir",
"Save new documents to" => "Guardar nuevo documento a",
"Wrong password. Please retry." => "Clave incorrecta. Intente de nuevo.",
"Password" => "Contraseña",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Este vínculo ha expirado o nunca existió. Por favor contacte a la persona que lo compartió con usted para más detalles.",
"Advanced feature-set" => "Características Avanzadas",
"(Unstable)" => "(Inestable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/es_AR.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documentos",
"You don't have permission to rename this document" => "No tienes permisos para cambiar de nombre a este documento.",
"Saved" => "Guardado",
"Saving..." => "Guardando...",
"Failed to load documents." => "La carga de documentos ha fallado.",
"No connection to server. Trying to reconnect." => "No hay conexión al servidor. Intentado reconectar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Salir de esta página en modo Editor puede causar pérdida de datos. Es recomendable usar el botón 'Cerrar'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Fallo al cargar este documento. Por favor, chequée si puede ser abierto con un editor odt externo. Esto también puede suceder si ha dejado de compartirse o ha sido borrado recietemente.",
"Save" => "Guardar",
"Loading documents..." => "Cargando documentos...",
"'.' is an invalid file name." => "'.' es un nombre de archivo inválido.",
"File name cannot be empty." => "El nombre del archivo no puede quedar vacío.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nombre invalido, '\\', '/', '<', '>', ':', '\"', '|', '?' y '*' no están permitidos.",
"Align Left" => "Alinear a la izquierda",
"Alignment" => "Alineación",
"Align Right" => "Alinear a la derecha",
"Annotate" => "Anotar",
"Background" => "Fondo",
"Bold" => "Negrita",
"Bottom" => "Abajo",
"Cancel" => "Cancelar",
"Center" => "Centro",
"Clone" => "Clonar",
"Clone this Style" => "Clonar este Estilo",
"Close" => "Cerrar",
"Color" => "Color",
"Create" => "Crear",
"Decrease Indent" => "Disminuir indentación",
"Default Style" => "Estilo Predefinido",
"Delete" => "Borrar",
"Family" => "Familia",
"Font" => "Fuente",
"Font Effects" => "Efectos de Fuente",
"Format" => "Formato",
"Increase Indent" => "Incrementar Indentación",
"Insert Image" => "Insertar Imágen",
"Invite Members" => "Invitar Miembros",
"Italic" => "Itálica",
"Justified" => "Justificado",
"Justify" => "Justificar",
"Left" => "Izquierda",
"Loading" => "Cargando",
"Members" => "Miembros",
"New Name:" => "Nuevo Nombre:",
"OK" => "Aceptar",
"Open" => "Abrir",
"Options" => "Opciones",
"Paragraph..." => "Párrafo...",
"Paragraph Styles" => "Estilos de Párrafo",
"Redo" => "Rehacer",
"Right" => "Derecha",
"Size" => "Tamaño",
"Spacing" => "Espaciado",
"Strikethrough" => "Tachado",
"Style" => "Estilo",
"Text" => "Texto",
"Top" => "Arriba",
"Underline" => "Subrayado",
"Undo" => "Deshacer",
"Unknown Author" => "Autor Desconocido",
"Shared" => "Compartido",
"Error" => "Error",
"Error while sharing" => "Error al compartir",
"Error while unsharing" => "Error en al dejar de compartir",
"Error while changing permissions" => "Error al cambiar permisos",
"Shared with you and the group {group} by {owner}" => "Compartido con vos y el grupo {group} por {owner}",
"Shared with you by {owner}" => "Compartido con vos por {owner}",
"Share" => "Compartir",
"Share link" => "Compartir vínculo",
"Password protect" => "Proteger con contraseña ",
"Password" => "Contraseña",
"Email link to person" => "Enviar el enlace por e-mail.",
"Send" => "Mandar",
"Set expiration date" => "Asignar fecha de vencimiento",
"Expiration" => "Vencimiento",
"Expiration date" => "Fecha de vencimiento",
"group" => "grupo",
"Resharing is not allowed" => "No se permite volver a compartir",
"Shared in {item} with {user}" => "Compartido en {item} con {user}",
"Unshare" => "Dejar de compartir",
"notify by email" => "notificar por correo",
"can share" => "puede compartir",
"can edit" => "podés editar",
"access control" => "control de acceso",
"create" => "crear",
"delete" => "borrar",
"Password protected" => "Protegido por contraseña",
"Error unsetting expiration date" => "Error al remover la fecha de vencimiento",
"Error setting expiration date" => "Error al asignar fecha de vencimiento",
"Sending ..." => "Mandando...",
"Email sent" => "e-mail mandado",
"Warning" => "Atención",
"Edit" => "Editar",
"Disabled" => "Deshabilitado",
"New document" => "Nuevo documento",
"Upload" => "Subir",
"Save new documents to" => "Guardar nuevo documento a",
"Wrong password. Please retry." => "Clave incorrecta. Intente de nuevo.",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Este vínculo ha expirado o nunca existió. Por favor contacte a la persona que lo compartió con usted para más detalles.",
"Advanced feature-set" => "Características Avanzadas",
"(Unstable)" => "(Inestable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
